@@ -1,4 +1,4 @@
-use clap::Clap;
+use clap::Parser;
 use lazy_static::*;
 use regex::Regex;
 use std::io::BufRead;
@@ -65,13 +65,6 @@ fn make_regex(com_syms: &Vec<String>) -> String {
     format!("({}):=\\s+(.*)", head)
 }
 
-#[derive(Default, Debug, Clone)]
-pub struct Config {
-    pub(super) filetypes: Vec<OsString>,
-    pub(super) ignore_dirs: Vec<OsString>,
-    pub(super) dirs: Vec<String>,
-}
-
 pub(super) fn make_key_regex(keywords: &Vec<String>) {
     let mut ss = String::new();
     for s in keywords {
@@ -84,6 +77,18 @@ pub(super) fn make_key_regex(keywords: &Vec<String>) {
     *kk = Some(Regex::new(&format!("({}):\\s*(.*)", ss)).unwrap());
 }
 
+pub fn clean_keywords_table() {
+    let mut kk = KEYWORDS_REGEX.lock().unwrap();
+    *kk = None;
+}
+
+#[derive(Default, Debug, Clone)]
+pub struct Config {
+    pub(super) filetypes: Vec<OsString>,
+    pub(super) ignore_dirs: Vec<OsString>,
+    pub(super) files: Vec<String>,
+}
+
 impl From<&Args> for Config {
     fn from(a: &Args) -> Self {
         match &a.jsonx {
@@ -103,7 +108,7 @@ impl From<&Args> for Config {
         Self {
             filetypes: a.filetypes.clone(),
             ignore_dirs: a.ignore_dirs.clone(),
-            dirs: a.dirs.clone(),
+            files: a.targets.clone(),
         }
     }
 }
@@ -144,17 +149,13 @@ pub fn parse_from_current_path_config() -> Option<Args> {
 
 //:= DOC: this doc in -h, remember update with version
 /// Command Line Args
-#[derive(Default, Clap, Debug)]
-#[clap(version = "0.1.6")]
+#[derive(Default, Parser, Debug)]
+#[clap(version = "0.2.2", author = "ccQpein")]
 pub struct Args {
     /// What are the filetypes you want to scan.
     #[clap(short, long)]
     filetypes: Vec<OsString>,
 
-    /// Specifically dirs code-it-later runs in
-    #[clap(short, long, default_value = ".")]
-    dirs: Vec<String>,
-
     /// The folder name should ignored
     #[clap(short = 'x', long = "ignore-dir")]
     ignore_dirs: Vec<OsString>,
@@ -166,6 +167,10 @@ pub struct Args {
     /// Expand dictionary json file path
     #[clap(short, long)]
     jsonx: Option<String>,
+
+    /// files/dirs input directly
+    #[clap(name = "files/dirs", default_value = ".")]
+    targets: Vec<String>,
 }
 
 impl Args {
@@ -176,10 +181,6 @@ impl Args {
             self.filetypes = other.filetypes
         }
 
-        if other.dirs.len() != 0 {
-            self.dirs = other.dirs
-        }
-
         if other.ignore_dirs.len() != 0 {
             self.ignore_dirs = other.ignore_dirs
         }
@@ -191,6 +192,10 @@ impl Args {
         if other.jsonx.is_some() {
             self.jsonx = other.jsonx
         }
+
+        if other.targets.len() != 0 {
+            self.targets = other.targets;
+        }
     }
 }
 
@@ -246,7 +251,7 @@ mod tests {
     #[test]
     fn test_update_table_with_json() {
         let mut buf = vec![];
-        File::open("./tests/test.json")
+        File::open("./tests/testcases/test.json")
             .unwrap()
             .read_to_end(&mut buf)
             .unwrap();
@@ -304,6 +309,25 @@ mod tests {
     fn test_parse_from_iter() {
         let args = vec!["codeitlater", "-x", "dd"];
         assert_eq!(Args::parse_from(args).ignore_dirs, vec!["dd"]);
+
+        // if there are some options, "--" is required
+        let args = vec!["codeitlater", "-x", "dd", "--", "a", "b", "c"];
+        assert_eq!(
+            Args::parse_from(args).targets,
+            vec!["a".to_string(), "b".to_string(), "c".to_string()]
+        );
+
+        let args = vec!["codeitlater", "--", "a", "b", "c"];
+        assert_eq!(
+            Args::parse_from(args).targets,
+            vec!["a".to_string(), "b".to_string(), "c".to_string()]
+        );
+
+        let args = vec!["codeitlater", "a", "b", "c"];
+        assert_eq!(
+            Args::parse_from(args).targets,
+            vec!["a".to_string(), "b".to_string(), "c".to_string()]
+        );
     }
 
     #[test]
